/* Include generic scientist behavior */
{ include("generic_scientist.asl") } 

/* Initial beliefs */
//percentage_rational(10).		// Percentage of rational cheaters
//max_review_distance(3).		// Maximum reviewing distance (used by the rational cheater strategy)
//reviews_x_paper(2)            // Number of reviews for each paper
type(sc).						// Type of scientist (sc -> correct; r_sc -> rational cheater)

/* Plans */
// Set-up plan
+!init : avg_quality_beta(AvgQA,AvgQB) & max_value(MaxValue) &
	     author_skill_beta(AuthSkillA,AuthSkillB) & percentage_rational(PtgeRat) &
		 reviewer_skill_beta(RevSkillA,RevSkillB)
   <- +author_skill(tools.beta(AuthSkillA,AuthSkillB)/2 + 0.5);
	  +reviewer_skill(tools.beta(RevSkillA,RevSkillB)/2 + 0.5);
	  +author_avg_quality(math.min(math.floor(tools.beta(AvgQA,AvgQB) * MaxValue) + 1, MaxValue));
	  if (tools.random(nextDouble) < PtgeRat/100)
	  {
	    +rational;
		-+type(r_sc)
	  }
	  !generic_init. 

// Correct reviewing strategy
+?review(_, IValue, _, _, Review) : not rational & reviewer_skill(RS) & max_value(MaxValue)
   <- if (tools.random(nextDouble) < RS)
      {  
        Review = IValue
	  } else {
        Review  = math.min(math.floor(tools.beta(1,1) * MaxValue) + 1, MaxValue)
	  }.

// Rational cheating reviewing strategy
+?review(_, IValue, AcceptValue, _, Review) : rational & author_avg_quality(AvgQ) & reviewer_skill(RS) & 
						 					  max_value(MaxValue) & reviews_x_paper(RxP) & max_review_distance(Rd)
   <- if (tools.random(nextDouble) < RS)
      {  
        EstimatedValue = IValue;
	  } else {
        EstimatedValue  = math.min(math.floor(tools.beta(1,1) * MaxValue) + 1, MaxValue);
	  }
	  if (EstimatedValue < AvgQ)
      {  
        Review = EstimatedValue;
	  } else {
        Review  = math.max(math.min(math.ceil((RxP*AcceptValue - (RxP-1)*EstimatedValue) - 1), IValue), EstimatedValue - Rd);
	  }.

